@@ -14,12 +14,13 @@ def format_time(string, mapping, trie=None):
     end = 1
     size = len(string)
     trie = trie or new_trie(mapping)
+    current = trie
     chunks = []
     sym = None
 
     while end <= size:
         chars = string[start:end]
-        result = in_trie(trie, chars)
+        result, current = in_trie(current, chars[-1])
 
         if result == 0:
             if sym:
@@ -28,6 +29,7 @@ def format_time(string, mapping, trie=None):
                 sym = None
             start += len(chars)
             chunks.append(chars)
+            current = trie
         elif result == 2:
             sym = chars
 
